pub struct RayIntersection {
pub time_of_impact: Real,
pub point: Vect,
pub normal: Vect,
pub feature: FeatureId,
}Expand description
Structure containing the result of a successful ray cast.
Fields
time_of_impact: RealThe time of impact of the ray with the object. The exact contact point can be computed
with origin + dir * time_of_impact where origin is the origin of the ray;
dir is its direction and time_of_impact is the value of this field.
point: VectThe intersection point between the ray and the object.
normal: VectThe normal at the intersection point.
If the toi is exactly zero, the normal might not be reliable.
feature: FeatureIdFeature at the intersection point.